summaryrefslogtreecommitdiffstats
path: root/kbabel/catalogmanager/catalogmanagerview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kbabel/catalogmanager/catalogmanagerview.h')
-rw-r--r--kbabel/catalogmanager/catalogmanagerview.h23
1 files changed, 12 insertions, 11 deletions
diff --git a/kbabel/catalogmanager/catalogmanagerview.h b/kbabel/catalogmanager/catalogmanagerview.h
index a1a23729..26a05d9f 100644
--- a/kbabel/catalogmanager/catalogmanagerview.h
+++ b/kbabel/catalogmanager/catalogmanagerview.h
@@ -22,11 +22,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -74,11 +74,12 @@ namespace KBabel
class PoInfo;
}
-class CatalogManagerView : public QListView
+class CatalogManagerView : public TQListView
{
Q_OBJECT
+ TQ_OBJECT
public:
- CatalogManagerView(KBabel::Project::Ptr project, TQWidget* parent=0, const char* name=0);
+ CatalogManagerView(KBabel::Project::Ptr project, TQWidget* tqparent=0, const char* name=0);
virtual ~CatalogManagerView();
KBabel::CatManSettings settings() const;
@@ -125,14 +126,14 @@ public slots:
* traverses all childs in the directory of the current item
* (including all subdirectories) and displays some statistics
* about the translations. If the item is a file, its
* parent directory is used instead.
*/
void statistics();
/**
* traverses all marked childs in the directory of the current item
* (including all subdirectories) and displays some statistics
* about the translations. If the item is a file, its
* parent directory is used instead.
*/
void markedStatistics();
/**
@@ -160,7 +161,7 @@ public slots:
void cvsUpdateMarked( );
void cvsCommit( );
void cvsCommitMarked( );
- void cvsStatus( );
+ void cvstqStatus( );
void cvsStatusMarked( );
void cvsUpdateTemplate( );
void cvsUpdateMarkedTemplate( );
@@ -184,7 +185,7 @@ public slots:
void svnInfo();
void svnInfoMarked();
- TQString find(KBabel::FindOptions &options, TQStringList &rest);
+ TQString tqfind(KBabel::FindOptions &options, TQStringList &rest);
void showLog();
@@ -193,7 +194,7 @@ public slots:
/**
* Stop searching, do not try to proceed to the next file
* @ref @find will return clear list of rest to be searched
- * and @ref TQString::null, if search string was not is the last searched file
+ * and @ref TQString(), if search string was not is the last searched file
*/
void stopSearch();
@@ -234,7 +235,7 @@ public slots:
/**
* Returns the list of all currently selected files. If current selection is dir,
- * it returns list of all its children.
+ * it returns list of all its tqchildren.
*/
TQStringList current();
/**
@@ -125,14 +126,14 @@ public slots:
* (including all subdirectories) and displays some statistics
* about the translations. If the item is a file, its
- * parent directory is used instead.
+ * tqparent directory is used instead.
*/
void statistics();
@@ -125,14 +126,14 @@ public slots:
* (including all subdirectories) and displays some statistics
* about the translations. If the item is a file, its
- * parent directory is used instead.
+ * tqparent directory is used instead.
*/
void markedStatistics();